@@ -1,6 +1,6 @@
 import os,pathlib
 from pkg_resources import resource_string
-fontPath = resource_string(__name__, 'fonts/nova/NovaMono-Regular.ttf')
+nova = resource_string(__name__, 'fonts/nova/NovaMono-Regular.ttf')
 """
 castoro = os.path.join(fontPath,'castoro/Castoro-Regular.ttf')
 texturina = os.path.join(fontPath,'texturina/Texturina-Regular-opsz=24.ttf')
